import IMask from "imask";
import "./assets/style.css";
import "normalize.css";
import JSConfetti from "js-confetti";
import { checkPasswordValidity, checkPasswordMatch } from "./password";
import {
  countryInput,
  zipInput,
  passwordInput,
  passwordConfirmInput,
  allInputs,
  submitBtn,
} from "./domelements";
import COUNTRY_REGEX from "./country";

const jsConfetti = new JSConfetti();

function validateForm() {
  return (
    countryInput.value.search(COUNTRY_REGEX) >= 0 &&
    checkPasswordValidity() &&
    checkPasswordMatch()
  );
}

const form = document.querySelector("#form");

IMask(zipInput, { mask: "00-000" });

function unfocusInputs() {
  allInputs.forEach((input) => {
    input.setAttribute("unfocused", 1);
  });
}

document.addEventListener("DOMContentLoaded", () => {
  form.addEventListener("submit", (event) => {
    event.preventDefault();
    if (validateForm()) {
      jsConfetti.addConfetti();
      const formData = new FormData(form);
      const formDataValue = formData.values();
      const [email, country, zip] = Array(5).fill(formDataValue.next().value);
      alert(
        `Success!\nEmail: ${email}\nCountry: ${country}\nZIP: ${zip}\nPassword: [redacted]`,
      );
    } else {
      alert("Hold up, one or more fields are invalid! Try again");
    }
  });
  countryInput.addEventListener("input", () => {
    countryInput.setAttribute(
      "input-valid",
      countryInput.value.search(COUNTRY_REGEX) >= 0,
    );
  });

  countryInput.addEventListener("change", () => {
    document.querySelector("#country-info").textContent =
      countryInput.value.search(COUNTRY_REGEX) >= 0 ? "" : "Invalid country";
  });

  passwordInput.addEventListener("input", checkPasswordValidity);
  passwordConfirmInput.addEventListener("input", checkPasswordValidity);

  allInputs.forEach((input) => {
    input.addEventListener("focusout", (event) => {
      event.target.setAttribute("unfocused", 1);
    });
  });
  submitBtn.addEventListener("click", unfocusInputs);

  passwordInput.addEventListener("input", () => {
    passwordInput.setAttribute("input-valid", checkPasswordValidity());
  });

  [passwordInput, passwordConfirmInput].forEach((input) =>
    input.addEventListener("input", () => {
      passwordConfirmInput.setAttribute("input-valid", checkPasswordMatch());
    }),
  );
});
